from setuptools import setup

setup(name='bi_dist',
      version='0.1',
      description='Gaussian distributions',
      packages=['bi_dist'],
      author_email = 'jnyfaah@gmaail.com',
      author = 'jennifer chukwu',
      zip_safe=False)
